@@ -567,11 +567,8 @@ build_languages_menu (GtkSpellChecker *spell)
       menu_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (mi));
 
       g_object_set (G_OBJECT (mi), "name", lang_tag, NULL);
-      if (strcmp (spell->priv->lang, lang_tag) == 0)
+      if (spell->priv->lang && strcmp (spell->priv->lang, lang_tag) == 0)
         active_item = mi;
-      else
-        g_signal_connect (mi, "activate",
-                          G_CALLBACK (language_change_callback), spell);
       gtk_widget_show (mi);
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
 
@@ -579,6 +576,25 @@ build_languages_menu (GtkSpellChecker *spell)
     }
   if (active_item)
     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (active_item), TRUE);
+  else
+    {
+      /* For the situation where no language is active (i.e.
+       * spell->priv->lang == NULL), create a "None" item which is active. */
+      mi = gtk_radio_menu_item_new_with_label (menu_group, _("None"));
+      gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi), TRUE);
+      gtk_widget_show (mi);
+    }
+  /* Connect signals to menu items after determining which one is active,
+   * since otherwise the signal is potentially already fired once (since the
+   * first item added to the group is active by default. */
+  for (; menu_group; menu_group = menu_group->next)
+    {
+        mi = menu_group->data;
+        if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)))
+          g_signal_connect (mi, "activate",
+                            G_CALLBACK (language_change_callback), spell);
+    }
 
   g_list_free (languages_cb_struct.langs);
 
@@ -1083,7 +1099,7 @@ gtk_spell_checker_get_language (GtkSpellChecker *spell)
  * Requests the list of available languages from the enchant broker.
  *
  * Returns: (transfer full) (element-type utf8): a #GList of the available languages.
- * Use g_list_free to free the list after use.
+ * Use g_list_free_full with g_free to free the list after use.
  *
  * Since: 3.0.3
  */
